import { putNewTrkseg } from './trkseg';

declare global {
  var db: any;
  var dbReady: boolean;
}

const originalDb = globalThis.db;
const originalDateNow = globalThis.Date.now;

describe('The trkseg module', () => {
  beforeEach(() => {
    globalThis.db = { put: jest.fn() };
    globalThis.Date.now = () => 0;
  });
  afterEach(() => {
    globalThis.db = originalDb;
    globalThis.Date.now = originalDateNow;
  });
  test('db.put() a new trk when required', async () => {
    putNewTrkseg({ gpx: 1234567890123456, trk: 123456, trkseg: 5 });
    await expect(globalThis.db.put).toBeCalledWith({
      _id: 'gpx/1234567890123456/3trk/123456/000005',
      _rev: undefined,
      doc: {
        trkpt: undefined,
        extensions: undefined,
      },
      type: 'trkseg',
    });
  });
  test('db.put() generates an id for the trk if needed', async () => {
    const id = await putNewTrkseg({ gpx: 1 });
    expect(id).toEqual({ gpx: 1, trk: 0, trkseg: 0 });
  });
  test('db.put() generates ids for both gpx and trk if needed', async () => {
    const id = await putNewTrkseg();
    expect(id).toEqual({ gpx: 4320000000000000, trk: 0, trkseg: 0 });
  });
});
